=======
History
=======

0.1.0 (2017-01-29)
------------------

* First release of the django-auto-healthchecks client for Cronitor.io
* Configure powerful healthchecks directly from urls.py
* Automatic updates if your routes change
